## Cross-reference for CELINE Core Ontology classes, object properties and data properties back to ToC

This section provides details for each class and property defined by CELINE Core Ontology.

### Classes

- Community Context
- Dataset Reference
- KPI Evaluation
- Scenario
- Simulation
- Simulation Run

### Community Contextc back to ToC or Class ToC

IRI: https://w3id.org/celine/ontology#CommunityContext

Operational context binding a PECO Energy Community with assets, datasets and simulations.

is in domain of
  has energy community op, has simulation op, uses asset op

### Dataset Referencec back to ToC or Class ToC

IRI: https://w3id.org/celine/ontology#DatasetReference

Reference to an external dataset used as input or produced as output. CELINE does not define dataset schemas.

is in range of
  produces dataset op, uses dataset op

### KPI Evaluationc back to ToC or Class ToC

IRI: https://w3id.org/celine/ontology#KPIEvaluation

Evaluation of a BIGG KPI in a specific Scenario or SimulationRun.

is in domain of
  evaluates KPI op
is in range of
  has KPI evaluation op

### Scenarioc back to ToC or Class ToC

IRI: https://w3id.org/celine/ontology#Scenario

Definition of assumptions, temporal scope and configuration for one or more simulations.

is in range of
  has scenario op

### Simulationc back to ToC or Class ToC

IRI: https://w3id.org/celine/ontology#Simulation

Abstract simulation definition independent from execution.

is in domain of
  has scenario op, has simulation run op
is in range of
  has simulation op

### Simulation Runc back to ToC or Class ToC

IRI: https://w3id.org/celine/ontology#SimulationRun

Concrete execution of a Simulation under a specific Scenario.

is in domain of
  has KPI evaluation op, produces dataset op, uses dataset op, uses observation op
is in range of
  has simulation run op

### Object Properties

- evaluates KPI
- has energy community
- has KPI evaluation
- has scenario
- has simulation
- has simulation run
- has time interval
- produces dataset
- uses asset
- uses dataset
- uses observation

### evaluates KPIop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#evaluatesKPI

has domain
  KPI Evaluation c
has range
  K P I c

### has energy communityop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#hasCommunity

has domain
  Community Context c
has range
  Energy Community c

### has KPI evaluationop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#hasKPIEvaluation

has domain
  Simulation Run c
has range
  KPI Evaluation c

### has scenarioop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#hasScenario

has domain
  Simulation c
has range
  Scenario c

### has simulationop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#hasSimulation

has domain
  Community Context c
has range
  Simulation c

### has simulation runop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#hasSimulationRun

has domain
  Simulation c
has range
  Simulation Run c

### has time intervalop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#hasTimeInterval

has range
  Time interval c

### produces datasetop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#producesDataset

has domain
  Simulation Run c
has range
  Dataset Reference c

### uses assetop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#usesAsset

References SAREF or SAREF4ENER devices.

has domain
  Community Context c
has range
  Device c

### uses datasetop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#usesDataset

has domain
  Simulation Run c
has range
  Dataset Reference c

### uses observationop back to ToC or Object Property ToC

IRI: https://w3id.org/celine/ontology#usesObservation

References SOSA observations (e.g. weather, sensors).

has domain
  Simulation Run c
has range
  Observation c

## Legend back to ToC

c: Classes
op: Object Properties